PhotoInfo class

Represents detailed information about a selected photo

Constructors

PhotoInfo({required String id, required String fileName, required int fileSizeBytes, required String fileSize, required PhotoDimensions dimensions, String? creationDate, required String fileType, String? assetIdentifier, String? filePath, List<int>? imageData, required double scale, required ImageOrientation orientation})
PhotoInfo.fromJson(Map<String, dynamic> json)
Creates a PhotoInfo instance from a JSON map
factory

Properties

aspectRatio double
Gets the aspect ratio of the image
no setter
assetIdentifier String?
Asset identifier from Photos library
final
creationDate String?
Creation date of the photo (ISO 8601 format)
final
dimensions PhotoDimensions
Image dimensions in pixels
final
fileName String
File name of the photo
final
filePath String?
Path to the temporary file
final
fileSize String
Formatted file size string (e.g., "2.5 MB")
final
fileSizeBytes int
File size in bytes
final
fileType String
File type/format (e.g., "JPEG", "PNG", "HEIC")
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the photo
final
imageData List<int>?
Image data as bytes (optional, may be null if filePath is used)
final
orientation ImageOrientation
Image orientation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Image scale factor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the PhotoInfo instance to a JSON map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited